<?php
/**
 * Class for handle ajax request
 */
if ( ! class_exists( 'IPSocialLocker_Ajax' )) {

    class IPSocialLocker_Ajax
    {
        /**
         * Take ajax action name
         *
         * @var string
         */
        protected $_action;
        
        /**
         * Take ajax action handlers
         *
         * @var array
         */
        protected $_handlers = array(
            
            'iplocker_save'         => 'save',
            'iplocker_log'          => 'log',
            'iplocker_delete'       => 'delete',
            'iplocker_getcontent'   => 'getContent',
            'iplocker_preview'      => 'preview',
        );
        
        /**
         * Class constructor
         *
         * @return void
         */
        public function __construct()
        {
        }
        
        /**
         * Get action name
         *
         * @return string
         */
        public function getAction()
        {
            return $this->_action;
        }
        
        /**
         * Set action
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function setAction( $action )
        {
            $this->_action = sanitize_title( $action );
        }
        
        /**
         * Execute request
         *
         * @param  string $action
         * @return IPShortcode_Ajax
         */
        public function exec()
        {
            $data = array_merge( $_GET, $_POST );
            if ( empty( $data['doajax'] ) || empty( $data['iplocker'] ) || empty( $data['action'] ) ) {
                return true;
            }
            $this->setAction( $data['action'] );
            
            $action   = $this->getAction();
            $handlers = (array)$this->_handlers;
            if ( array_key_exists( $action, $handlers )) {
                $handler = $handlers[$action];
                if ( method_exists( $this, $handler )) {
                    $this->$handler();
                }
            }
            return true;
        }
        
        /**
         * Mendapatkan konten preview
         *
         * @return void
         */
        public function preview()
        {
            $factory = new IPSocialLocker_Factory();
            $preview = $factory->postPreview();
            
            echo json_encode( array( 'preview' => $preview ) );
            die();
        }
        
        /**
         * Menyimpan data pengaturan
         *
         * @return void
         */
        public function save()
        {
            $id = $this->_saveSetting();
            $result['id'] = $id;
            if ( $id ) {
                $result['status'] = 1;
            } else {
                $result['status'] = 0;
            }
            echo json_encode( $result );
            die();
        }
        
        /**
         * Menyimpan data log
         *
         * @return void
         */
        public function log()
        {
            global $wpdb, $table_prefix;
            
            $data = array_merge( $_POST, $_GET );
            if ( empty( $data['locker_id'] ) || empty( $data['post_id'] ) || empty( $data['type'] )) {
                
                echo json_encode( array( 'status' => 0 ) );
                die();
            }
            $type   = trim( $data['type'] );
            $id     = absint( $data['locker_id'] );
            $postId = absint( $data['post_id'] );
            
            if ( ! $locker = get_post( $id ) ) {
            
                echo json_encode( array( 'status' => 0 ) );
                die();
            }
            
            $tableName = $table_prefix . 'ip_social_tracking';
            
            //Get locker log data
            $count  = 0;
            $total  = 0;
            $date   = date( 'Y-m-d' );
            $query  = "SELECT * FROM $tableName WHERE aggregate_date = '$date' AND post_id = $postId";
            $result = $wpdb->get_results( $query );

            //Get count based on type
            if ( ! empty( $result ) ) {
            
                $log = $result[0];
                switch( $type ) {
                
                    case 'facebooklike' :
                        $count  = $log->facebook_like_count;
                        break;
                    case 'facebookshare' :
                        $count  = $log->facebook_share_count;
                        break;
                    case 'twittertweet' :
                        $count  = $log->twitter_tweet_count;
                        break;
                    case 'twitterfollow' :
                        $count  = $log->twitter_follow_count;
                        break;
                    case 'googleplus' :
                        $count  = $log->google_plus_count;
                        break;
                    case 'googleshare' :
                        $count  = $log->google_share_count;
                        break;
                    case 'linkedinshare' :
                        $count  = $log->linkedin_share_count;
                        break;
                    case 'timer' :
                        $count  = $log->timer_count;
                        break;
                    case 'close' :
                        $count  = $log->close_count;
                        break;
                }
                $total = $log->total_count;
            }
            $count++;
            $total++;
            
            switch( $type ) {
                
                case 'facebooklike' :
                    $column = 'facebook_like_count';
                    break;
                case 'facebookshare' :
                    $column = 'facebook_share_count';
                    break;
                case 'twittertweet' :
                    $column = 'twitter_tweet_count';
                    break;
                case 'twitterfollow' :
                    $column = 'twitter_follow_count';
                    break;
                case 'googleplus' :
                    $column = 'google_plus_count';
                    break;
                case 'googleshare' :
                    $column = 'google_share_count';
                    break;
                case 'linkedinshare' :
                    $column = 'linkedin_share_count';
                    break;
                case 'timer' :
                    $column = 'timer_count';
                    break;
                case 'close' :
                    $column = 'close_count';
                    break;
            }
            
            //Begin insert data
            if ( ! empty( $result ) ) {
            
                $toUpdate = array(
                    $column             => $count,
                    'total_count'       => $total
                );
                $wpdb->update( $tableName, $toUpdate, array( 'id' => $result[0]->id ) );
            } else {
            
                $toInsert = array(
                    'aggregate_date'    => $date,
                    'post_id'           => $postId,
                    $column             => $count,
                    'total_count'       => $total
                );
                $wpdb->insert( $tableName, $toInsert );
            }
          
            $result = array( 'status' => 1 );
            echo json_encode( $result );
            die();
        }
        
        /**
         * Mendapatkan content locker
         *
         * @return void
         */
        public function getContent()
        {
            
            $data = array_merge( $_POST, $_GET );
            if ( ! empty( $data['locker_id'] ) && ! empty( $data['post_id'] ) ) {
                
                $lockId = absint( $data['locker_id'] );
                $postId = absint( $data['post_id'] );
                if ( $post = get_post( $postId ) ) {
                
                    $pattern = get_shortcode_regex();
                    preg_match( "/$pattern/s", $post->post_content, $matches );
                    
                    if ( isset( $matches[2] ) && 
                         isset( $matches[3] ) &&
                         isset( $matches[5] ) &&
                         $matches[2] == 'wp-sociallocker'
                    ) {
                        $attr = shortcode_parse_atts( $matches[3] );
                        if ( isset( $attr['id'] ) && $attr['id'] == $lockId ) {
                            echo json_encode( array( 'content' => $matches[5] ) );
                            die();
                        }
                    }
                }
            }
            echo 0;
            die();
        }
        
        /**
         * Mendapatkan content locker
         *
         * @return void
         */
        public function shortcodeContent( $match )
        {
        }
        
        /**
         * Menyimpan data pengaturan
         *
         * @return int
         */
        protected function _saveSetting()
        {
            $data   = $this->_getDataSetting();
            if ( ! empty( $_POST['locker_id'] )) {
                $id = absint( $_POST['locker_id'] );
                $this->_edit( $id );
            } else {
                $id = $this->_add();
            }
            if ( ! empty( $id )) {
                $setting = new IPSocialLocker_Setting( $id );
                $setting->setSettings( $data );
            }
            return $id;
        }
        
        /**
         * Edit locker
         *
         * @param  int   $id
         * @return int
         */
        protected function _edit( $id )
        {
            $result = 0;
            if ( $locker = get_post( $id )) {
                if ( ! empty( $_POST['post_title'] ) && $_POST['post_title'] != $locker->post_title ) {
                    $data['post_title'] = apply_filters( 'single_post_title', $_POST['post_title'] );
                }
                if ( ! empty( $data )) {
                    $data['ID'] = $locker->ID;
                    $result = wp_update_post( $data );
                }
            }
            return $result;
        }
        
        /**
         * Add locker
         *
         * @return int
         */
        protected function _add()
        {
            global $user_ID;
            if ( empty( $_POST['post_title'] )) {
                $title = 'Unknown';
            } else {
                $title = apply_filters( 'single_post_title', $_POST['post_title'] );
            }
            $dataPost = array(
                'post_status'   => 1,
                'post_type'     => 'ipsociallocker', 
                'post_author'   => $user_ID,
                'post_date'     => date('c'),
                'post_title'    => $title
            );
            $result = wp_insert_post( $dataPost );
            return $result;
        }
        
        /**
         * Mendapatkan data pengaturan
         *
         * @return array
         */
        protected function _getDataSetting()
        {
            $data  = array();
            
            if ( isset( $_POST['locker_header'] )) {
                $data['locker_header'] = apply_filters( 'single_post_title', $_POST['locker_header'] );
            }
            if ( isset( $_POST['locker_message'] )) {
                $data['locker_message'] = $_POST['locker_message'];
            }
            
            //Social option
            $socopts = array(
                'fblike',
                'fbshare',
                'tweet',
                'twfollow',
                'gplus',
                'gpshare',
                'inshare',
            );
            foreach( $socopts as $tag ) {
                $id = $tag.'_available';
                if ( isset( $_POST[$id] )) {
                    $data[$id] = preg_replace( '@[^a-zA-Z]@', '', $_POST[$id] );
                }
                $id = $tag.'_url';
                if ( isset( $_POST[$id] )) {
                    $data[$id] = apply_filters( 'pre_link_url', $_POST[$id] );
                }
                $id = $tag.'_title';
                if ( isset( $_POST[$id] )) {
                    $data[$id] = apply_filters( 'single_post_title', $_POST[$id] );
                }
                $id = $tag.'_type';
                if ( isset( $_POST[$id] )) {
                    $data[$id] = absint( $_POST[$id] );
                }
            }
            
            //Design options
            if ( isset( $_POST['box_layout'] )) {
                $data['box_layout'] = absint( $_POST['box_layout'] );
            }
            if ( isset( $_POST['box_design'] )) {
                $data['box_design'] = absint( $_POST['box_design'] );
            }
            if ( isset( $_POST['button_design'] )) {
                $data['button_design'] = absint( $_POST['button_design'] );
            }
            
            //Adv Functions
            if ( isset( $_POST['close_icon'] )) {
                $data['close_icon'] = preg_replace( '@[^a-zA-Z]@', '', $_POST['close_icon'] );
            }
            if ( isset( $_POST['time_interval'] )) {
                $data['time_interval'] = absint( $_POST['time_interval'] );
            }
            if ( isset( $_POST['ajax_support'] )) {
                $data['ajax_support'] = preg_replace( '@[^a-zA-Z]@', '', $_POST['ajax_support'] );
            }
            if ( isset( $_POST['mobile_support'] )) {
                $data['mobile_support'] = preg_replace( '@[^a-zA-Z]@', '', $_POST['mobile_support'] );
            }
            if ( isset( $_POST['highlight'] )) {
                $data['highlight'] = preg_replace( '@[^a-zA-Z]@', '', $_POST['highlight'] );
            }
            if ( isset( $_POST['hide_member'] )) {
                $data['hide_member'] = preg_replace( '@[^a-zA-Z]@', '', $_POST['hide_member'] );
            }
            if ( isset( $_POST['close_position'] )) {
                $data['close_position'] = absint( $_POST['close_position'] );
            }
            if ( isset( $_POST['timer_position'] )) {
                $data['timer_position'] = absint( $_POST['timer_position'] );
            }
            if ( isset( $_POST['show_alert_msg'] )) {
                $data['show_alert_msg'] = preg_replace( '@[^a-zA-Z]@', '', $_POST['show_alert_msg'] );
            }
            if ( isset( $_POST['alert_message'] )) {
                $data['alert_message'] = $_POST['alert_message'];
            }
            
            if ( isset( $_POST['socorder'] )) {
                $data['button_order'] = $_POST['socorder'];
            }
            
            return $data;
        }
        
        /**
         * Processing ajax for delete locker
         *
         * @return void
         */
        public function delete()
        {
            $locker = false;
            if ( ! empty( $_REQUEST['id'] )) {
                $id     = absint( $_REQUEST['id'] );
                $locker = get_post( $id );
            }
            if ( ! $locker ) {
                echo json_encode( array(
                    'status'  => 0,
                    'data'    => array(
                        'message'  => __( 'Error system' )
                    )
                ) );
                die();
            }
            $result = wp_delete_post( $locker->ID, true );
            if ( $result ) {
                echo json_encode( array(
                    'status'  => 1,
                    'data'    => array(
                        'message'  => __( 'Successfully remove the locker' )
                    )
                ) );
            } else {
                echo json_encode( array(
                    'status'  => 0,
                    'data'    => array(
                        'message'  => __( 'Failed to remove the locker' )
                    )
                ) );
            }
            die();
        }
    }
    
}
?>