<?php
/**
 * Class for build count down
 */
if ( ! class_exists( 'IPSocialLocker_Factory' )) {

    class IPSocialLocker_Factory
    {
        /**
         * Take layout functions
         *
         * @var array
         */
        protected $_layoutFunc = array(
            1 => '_getLayout1',
            2 => '_getLayout2',
            3 => '_getLayout3',
            4 => '_getLayout4',
        );
        
        /**
         * Take layout tag
         *
         * @var array
         */
        protected $_layoutClass = array(
            1 => 'ip-lockbox-center',
            2 => 'ip-lockbox-left',
            3 => 'ip-lockbox-iboxleft',
            4 => 'ip-lockbox-iboxright',
        );
        
        /**
         * Take buttons Func
         *
         * @var array
         */
        protected $_buttonFunc = array(
            'fblike'    => '_getButtonFacebookLike',
            'fbshare'   => '_getButtonFacebookShare',
            'tweet'     => '_getButtonTwitterTweet',
            'twfollow'  => '_getButtonTwitterFollow',
            'gplus'     => '_getButtonGooglePlus',
            'gpshare'   => '_getButtonGoogleShare',
            'inshare'   => '_getButtonLinkedIn',
        );
        
        /**
         * Create shortcode content
         *
         * @param  array  $atts
         * @param  string $content
         * @return string
         */
        public function create( $atts, $content = '')
        {
            global $post;
            
            $result   = $content;
            $metas    = get_post_meta( $post->ID, '_ip_post_lock' );
            $lockerId = 0;
            if ( ! empty( $metas )) {
                $lockerId = array_shift( $metas );
                $lockerId = absint( $lockerId );
            }
            if ( ! empty( $lockerId ) ) {
                return $result;
            }
            
            if ( ! empty( $atts['id'] ) ) {
                $lockerId = absint( $atts['id'] );
                if ( $locker = get_post( $lockerId ) ) {
                    $setting = new IPSocialLocker_Setting( $locker->ID );
                    if ( $this->_showLocker( $locker, $setting ) ) {
                        $result  = $this->_getContentLocker( $locker, $content, $setting );
                        $result .= $this->_getLocker( $setting );
                    }
                    $result = $this->_getWrapper( $result, $locker, $setting );
                }
            }
            return $result;
        }
        
        /**
         * Create post locker content
         *
         * @param  string $content
         * @return string
         */
        public function postLocker( $content = '' )
        {
            global $post;
            
            $result   = $content;
            $metas    = get_post_meta( $post->ID, '_ip_post_lock' );
            $lockerId = 0;
            if ( ! empty( $metas )) {
                $lockerId = array_shift( $metas );
                $lockerId = absint( $lockerId );
            }
            if ( ! empty( $lockerId ) ) {
                if ( $locker = get_post( $lockerId ) ) {
                    $setting = new IPSocialLocker_Setting( $locker->ID );
                    if ( $this->_showLocker( $locker, $setting ) ) {
                        $result  = $this->_getContentLocker( $locker, $content, $setting );
                        $result .= $this->_getLocker( $setting );
                    }
                    $result = $this->_getWrapper( $result, $locker, $setting );
                }
            }
            return $result;
        }
        
        /**
         * Create locker preview
         *
         * @param  string $content
         * @return string
         */
        public function postPreview()
        {
            $result = '';
            $data   = array_merge( $_POST, $_GET );
            if ( ! empty( $data )) {
                $setting = new IPSocialLocker_Setting_Custom( $data );
                $plgurl  = plugin_dir_url( dirname(__FILE__) );
                $result .= '<link rel="stylesheet" href="'.$plgurl.'css/style.css" type="text/css" media="all">';
                $result .= $this->_getInit( $setting );
                $result .= $this->_getLocker( $setting );
            }
            return $result;
        }
        
        /**
         * Create locker preview
         *
         * @param  string $content
         * @return string
         */
        public function preview( $locker )
        {
            $result  = '';
            $setting = new IPSocialLocker_Setting( $locker->ID );
            $plgurl  = plugin_dir_url( dirname(__FILE__) );
            $result .= '<link rel="stylesheet" href="'.$plgurl.'css/style.css" type="text/css" media="all">';
            $result .= $this->_getInit( $setting );
            $result .= $this->_getLocker( $setting );
            
            return $result;
        }
        
        /**
         * Check if need to show locker
         *
         * @param  object $locker
         * @param  object $setting
         * @return boolean
         */
        protected function _showLocker( $locker, $setting )
        {
            global $user_ID;
            
            $cookiekey  = 'iplocker_open_id'.$locker->ID;
            $hideMember = $setting->getSetting( 'hide_member', 'true' );
            if ( ! empty( $user_ID ) && $hideMember == 'true' ) {
                return false;
            } elseif ( isset( $_COOKIE[$cookiekey] )) {
                return false;
            }
            return true;
        }
        
        /**
         * Get content locker
         *
         * @param array $setting
         * @return string
         */
        protected function _getLocker( $setting )
        {
            $result  = '';
            $theme   = $setting->getSetting( 'box_design', 1 );
            $layout  = $setting->getSetting( 'box_layout', 1 );
            
            $class   = 'ip-locker ip-lockbox-'.$theme;
            if ( array_key_exists( $layout, $this->_layoutClass )) {
                $class .= ' '.$this->_layoutClass[$layout];
            }
            
            $result .= '<div class="'.$class.'">
                            <div class="ip-lockbox-skin">
                                <div class="ip-lockbox-inner">
                                    ' . $this->_getLayout( $setting ) . '
                                    ' . $this->_getTimer( $setting ) . '
                                    ' . $this->_getClose( $setting ) . '
                                </div>
                            </div>
                        </div>';
            
            return $result;
        }
        
        /**
         * Get content layout
         *
         * @param array $setting
         * @return string
         */
        protected function _getLayout( $setting )
        {
            $result = '';
            $layout = $setting->getSetting( 'box_layout', 1 );
            if ( array_key_exists( $layout, $this->_layoutFunc )) {
                $func   = $this->_layoutFunc[$layout];
                $result = $this->$func( $setting );
            }
            return $result;
        }
        
        /**
         * Get timer function
         *
         * @param array $setting
         * @return string
         */
        protected function _getTimer( $setting )
        {
            $result = '';
            $timer  = $setting->getSetting( 'time_interval', 0 );
            $pos    = $setting->getSetting( 'timer_position', 1 );
            $timer  = (int)$timer;
            if ( $timer > 0 ) {
                $result .= '<div class="ip-locker-timer ip-timer-pos-'.$pos.'" data-interval="'.$timer.'">
                                ' . __( 'Or wait' ) . ' <span class="ip-timer-second">' . $timer . '</span>s
                            </div>';
            }
            return $result;
        }
        
        /**
         * Get close function
         *
         * @param array $setting
         * @return string
         */
        protected function _getClose( $setting )
        {
            $result = '';
            $close  = $setting->getSetting( 'close_icon', 'true' );
            $pos    = $setting->getSetting( 'close_position', 1 );
            if ( $close == 'true' ) {
                $result .= '<div class="ip-locker-close ip-close-pos-'.$pos.'">
                                <a href="#">Close</a>
                            </div>';
            }
            return $result;
        }
        
        /**
         * Get content layout
         *
         * @param array $setting
         * @return string
         */
        protected function _getLayout1( $setting )
        {
            $result  = '<div class="ip-lock-content ip-clear">
                            <div class="ip-lock-content-main">
                                ' . $this->_getLockerHeader( $setting ) . '
                                ' . $this->_getLockerMessage( $setting ) . '
                                ' . $this->_getLockerButtons( $setting ) . '
                            </div>
                        </div>';
            return $result;
        }
        
        /**
         * Get content layout
         *
         * @param array $setting
         * @return string
         */
        protected function _getLayout2( $setting )
        {
            $result = $this->_getLayout1( $setting );
            return $result;
        }
        
        /**
         * Get content layout
         *
         * @param array $setting
         * @return string
         */
        protected function _getLayout3( $setting )
        {
            $result  = '<div class="ip-lock-content ip-clear">
                            ' . $this->_getLockerThumb( $setting ) . '
                            <div class="ip-lock-content-main">
                                ' . $this->_getLockerHeaderSide( $setting ) . '
                                ' . $this->_getLockerMessage( $setting ) . '
                                ' . $this->_getLockerButtons( $setting ) . '
                            </div>
                        </div>';
            return $result;
        }
        
        /**
         * Get content layout
         *
         * @param array $setting
         * @return string
         */
        protected function _getLayout4( $setting )
        {
            $result = $this->_getLayout3( $setting );
            return $result;
        }
        
        /**
         * Get locker header
         *
         * @param array $setting
         * @return string
         */
        protected function _getLockerHeader( $setting )
        {
            $result = '<div class="ip-lock-header">
                            <h2 class="ip-lock-title">
                                <span class="ip-icon-left"></span>
                                ' . $setting->getSetting( 'locker_header', '' ) . '
                                <span class="ip-icon-right"></span>
                            </h2>
                        </div>';
            return $result;
        }
        
        /**
         * Get locker header 
         *
         * @param array $setting
         * @return string
         */
        protected function _getLockerHeaderSide( $setting )
        {
            $result = '<div class="ip-lock-header">
                            <h2 class="ip-lock-title">
                                <span class="ip-icon-left"></span>
                                ' . $setting->getSetting( 'locker_header', '' ) . '
                            </h2>
                        </div>';
            return $result;
        }
        
        /**
         * Get locker message
         *
         * @param array $setting
         * @return string
         */
        protected function _getLockerMessage( $setting )
        {
            $result = '<div class="ip-lock-message">
                            ' . $setting->getSetting( 'locker_message', '' ) . '
                       </div>';
            return $result;
        }
        
        /**
         * Get locker thumb icon
         *
         * @param array $setting
         * @return string
         */
        protected function _getLockerThumb( $setting )
        {
            $plgurl = plugin_dir_url( dirname(__FILE__) );
            $result = '<div class="ip-lock-thumb"><img src="' . $plgurl . 'img/lock-thumb.png" alt="" /></div>';
            return $result;
        }
        
        
        /**
         * Get social buttons
         *
         * @param array $setting
         * @return string
         */
        protected function _getLockerButtons( $setting )
        {
            $result  = '';
            $order   = $setting->getSetting( 'button_order' );
            $order   = trim( $order, '|' );
            $buttons = explode( '|', $order );
            
            $result  = '<div class="ip-lock-button">';
            if ( ! empty( $buttons )) {
                foreach( $buttons as $button ) {
                    $on = $setting->getSetting( $button.'_available' );
                    if ( $on && $on == 'true' ) {
                        
                        if ( array_key_exists( $button, $this->_buttonFunc )) {
                            $func    = $this->_buttonFunc[$button];
                            if ( method_exists( $this, $func )) {
                                $result .= $this->$func( $setting );
                            }
                        }
                    }
                }
            }
            $result .= '</div>';
            return $result;
        }
        
        /**
         * Get FB Like button
         *
         * @param  object  $setting
         * @return string
         */
        protected function _getButtonFacebookLike( $setting )
        {
            $style  = $setting->getSetting( 'button_design', 1 );
            $label  = $setting->getSetting( 'fblike_title', 'Like' );
            $href   = $setting->getSetting( 'fblike_url' );
            $appId  = get_option( '_iplock_facebook_appid', '239219112897202' );
            if ( $style == 8 || $style == 9 || $style == 10 ) {
                $type = 'box_count';
            } else {
                $type = 'button_count';
            }
            $datahref = '';
            if ( $href ) {
                $datahref = ' data-href="'.$href.'"';
            }
            $class  = 'ip-socbtn ip-socbtn-facebook ip-socbtn-style' . $style;
            $result = ' <div class="'.$class.'">
                            <div class="ip-socbtn-like">
                                <div class="ipsl-socbtn-fblike" data-appid="'.$appId.'" data-layout="'.$type.'"'.$datahref.'></div>
                            </div>'
                            . $this->_getBoxEffect( $label, $style ) . 
                        '</div>';
            return $result;
        }
        
        /**
         * Get FB Share button
         *
         * @param  object  $setting
         * @return string
         */
        protected function _getButtonFacebookShare( $setting )
        {
            $style    = $setting->getSetting( 'button_design', 1 );
            $label    = $setting->getSetting( 'fbshare_title', 'Share' );
            $href     = $setting->getSetting( 'fbshare_url' );
            $appId    = get_option( '_iplock_facebook_appid', '239219112897202' );
            $datahref = '';
            if ( $href ) {
                $datahref = ' data-href="'.$href.'"';
            }
            if ( $style == 8 || $style == 9 || $style == 10 ) {
                $type = 'box-count';
            } else {
                $type = 'button-count';
            }
            $class  = 'ip-socbtn ip-socbtn-facebook ip-socbtn-style' . $style;
            $result = ' <div class="'.$class.'">
                            <div class="ip-socbtn-like">
                                <div class="ipsl-socbtn-fbshare" data-appid="'.$appId.'" data-layout="'.$type.'"'.$datahref.'></div>
                            </div>'
                            . $this->_getBoxEffect( $label, $style ) . 
                        '</div>';
            return $result;
        }
        
        /**
         * Get Twitter tweet button
         *
         * @param  object  $setting
         * @return string
         */
        protected function _getButtonTwitterTweet( $setting )
        {
            $style    = $setting->getSetting( 'button_design', 1 );
            $label    = $setting->getSetting( 'tweet_title', 'Tweet' );
            $href     = $setting->getSetting( 'tweet_url' );
            $datahref = '';
            if ( $href ) {
                $datahref = ' data-href="'.$href.'"';
            }
            if ( $style == 8 || $style == 9 || $style == 10 ) {
                $type = 'vertical';
            } else {
                $type = 'horizontal';
            }
            $style  = $setting->getSetting( 'button_design', 1 );
            $class  = 'ip-socbtn ip-socbtn-twitter ip-socbtn-style' . $style;
            $result = ' <div class="'.$class.'">
                            <div class="ip-socbtn-like">
                                <div class="ipsl-socbtn-twtweet" data-size="medium" data-count="'.$type.'" data-text="'.$label.'"'.$datahref.'></div>
                            </div>'
                            . $this->_getBoxEffect( $label, $style ) . 
                        '</div>';
            return $result;
        }
        
        /**
         * Get Twitter follow button
         *
         * @param  object  $setting
         * @return string
         */
        protected function _getButtonTwitterFollow( $setting )
        {
            $style    = $setting->getSetting( 'button_design', 1 );
            $label    = $setting->getSetting( 'twfollow_title', 'Follow' );
            $href     = $setting->getSetting( 'twfollow_url' );
            $datahref = '';
            if ( $href ) {
                $datahref = ' data-href="'.$href.'"';
            }
            if ( $style == 8 || $style == 9 || $style == 10 ) {
                $type = 'vertical';
            } else {
                $type = 'horizontal';
            }
            $class  = 'ip-socbtn ip-socbtn-twitter ip-socbtn-twitter-follow ip-socbtn-style' . $style;
            $result = ' <div class="'.$class.'">
                            <div class="ip-socbtn-like">
                                <div class="ipsl-socbtn-twfollow" data-size="medium" data-count="'.$type.'" data-text="'.$label.'"'.$datahref.'></div>
                            </div>'
                            . $this->_getBoxEffect( $label, $style ) . 
                        '</div>';
            return $result;
        }
        
        /**
         * Get google plus button
         *
         * @param  object  $setting
         * @return string
         */
        protected function _getButtonGooglePlus( $setting )
        {
            $style    = $setting->getSetting( 'button_design', 1 );
            $label    = $setting->getSetting( 'gplus_title', 'Google +1' );
            $href     = $setting->getSetting( 'gplus_url' );
            $datahref = '';
            if ( $href ) {
                $datahref = ' data-href="'.$href.'"';
            }
            if ( $style == 8 || $style == 9 || $style == 10 ) {
                $type = 'tall';
            } else {
                $type = 'medium';
            }
            $class  = 'ip-socbtn ip-socbtn-google ip-socbtn-style' . $style;
            $result = ' <div class="'.$class.'">
                            <div class="ip-socbtn-like">
                                <div class="ipsl-socbtn-gplus" data-size="'.$type.'"'.$datahref.'></div>
                            </div>'
                            . $this->_getBoxEffect( $label, $style ) . 
                        '</div>';
            return $result;
        }
        
        /**
         * Get google share button
         *
         * @param  object  $setting
         * @return string
         */
        protected function _getButtonGoogleShare( $setting )
        {
            $style    = $setting->getSetting( 'button_design', 1 );
            $label    = $setting->getSetting( 'gpshare_title', 'Share' );
            $href     = $setting->getSetting( 'gpshare_url' );
            $datahref = '';
            if ( $href ) {
                $datahref = ' data-href="'.$href.'"';
            }
            if ( $style == 8 || $style == 9 || $style == 10 ) {
                $type = 'vertical-bubble';
            } else {
                $type = 'bubble';
            }
            $class  = 'ip-socbtn ip-socbtn-google ip-socbtn-style' . $style;
            $result = ' <div class="'.$class.'">
                            <div class="ip-socbtn-like">
                                <div class="ipsl-socbtn-gshare" data-annotation="'.$type.'"'.$datahref.'></div>
                            </div>'
                            . $this->_getBoxEffect( $label, $style ) . 
                        '</div>';
            return $result;
        }
        
        /**
         * Get linkedin share button
         *
         * @param  object  $setting
         * @return string
         */
        protected function _getButtonLinkedin( $setting )
        {
            $style    = $setting->getSetting( 'button_design', 1 );
            $label    = $setting->getSetting( 'inshare_title', 'Share' );
            $href     = $setting->getSetting( 'inshare_url' );
            $datahref = '';
            if ( $href ) {
                $datahref = ' data-href="'.$href.'"';
            }
            if ( $style == 8 || $style == 9 || $style == 10 ) {
                $type = 'top';
            } else {
                $type = 'right';
            }
            $class  = 'ip-socbtn ip-socbtn-linkedin ip-socbtn-style' . $style;
            $result = ' <div class="'.$class.'">
                            <div class="ip-socbtn-like">
                                <div class="ipsl-socbtn-inshare" data-counter="'.$type.'"'.$datahref.'></div>
                            </div>'
                            . $this->_getBoxEffect( $label, $style ) . 
                        '</div>';
            return $result;
        }
        
        /**
         * Get content locker
         *
         * @param object $locker
         * @param string $content
         * @param array  $setting
         * @return string
         */
        protected function _getContentLocker( $locker, $content, $setting )
        {
            $hide = ' style="display:none;"';
            $key  = 'iplocker_open_id'.$locker->ID;
            if ( isset( $_COOKIE[$key] )) {
                $hide = '';
            }
            $ajax = $setting->getSetting( 'ajax_support', 'false' );
            if ( $ajax == 'false' ) {
                $result  = '<div class="iplock-content-wrapper"'.$hide.'>';
                $result .= '<div><div><div><div><div><div class="iplock-content-inner"'.$hide.'>';
                $result .= $content;
                $result .= '</div></div></div></div></div></div>';
                $result .= '</div>';
             
            } else {
                $result  = '<div class="iplock-content-wrapper" style="display: none;">
                                <div class="iplock-content-ajax">
                                </div>
                            </div>';
            }
            
            return $result;
        }
        
        /**
         * Get content locker
         *
         * @param string $label
         * @param int    $style
         * @return string
         */
        protected function _getBoxEffect( $label, $style )
        {
            $result = '';
            if ( $style == 1 ) {
                
                $result = '<div class="ip-box-effect" style="z-index: 50;">
                                <div class="ip-socbtn-label" style="z-index: 50;">'.$label.'</div>
                                <div class="ip-box-effect-header" style="z-index: 49;"></div>
                                <div class="ip-box-effect-back" style="z-index: 49;"></div>
                            </div>';
            
            } else {
                
                $result = '<div class="ip-box-effect">
                                <span class="ip-socbtn-icon"></span>
                                <span class="ip-socbtn-label">'.$label.'</span>
                            </div>';
            }
            return $result;
        }
        
        /**
         * Get wrapper
         *
         * @param  string $content
         * @param  object $locker
         * @param  object $setting
         * @return string
         */
        protected function _getWrapper( $content, $locker, $setting )
        {
            global $post;
            
            $class  = 'iplock-item';
            $mobile = $setting->getSetting( 'mobile_support', 'true' );
            $ajax   = $setting->getSetting( 'ajax_support', 'false' );
            $alert  = $setting->getSetting( 'show_alert_msg', 'false' );
            $msg    = $setting->getSetting( 'alert_message', 'Content is unlocked' );
            if ( $mobile == 'false' ) {
                $class .= ' iplock-hide-inmobile';
            }
            if ( $ajax == 'true' ) {
                $class .= ' iplock-support-ajax';
            }
            if ( $alert == 'true' ) {
                $class .= ' iplock-support-alert';
            }
            $result  = $this->_getInit( $setting );
            $result .= '<div id="iplocker-'.$locker->ID.'" data-postid="'.$post->ID.'" class="'.$class.'">';
            $result .= $content;
            if ( $alert == 'true' ) {
                $result .= '<div style="display:none;">
                                <p class="ipsl-alert-message">'.$msg.'</p>
                            </div>';
            }
            $result .= '</div>';
            return $result;
        }
        
        /**
         * Get init
         *
         * @param  array $setting
         * @return string
         */
        protected function _getInit( $setting )
        {
            $result = '';
            //Add Script
            $result .= '<script type="text/javascript">
                            var ajaxurl = "' . admin_url('admin-ajax.php') . '";
                            var iplocker_settings = {
                            
                                highlight: "' . $setting->getSetting( 'highlight', 'true' ) . '",
                                ajaxSupport: "' . $setting->getSetting( 'ajax_support', 'true' ) . '",
                            };
                       </script>';
            
            return $result;
        }
    }
}
?>