<?php
if ( ! class_exists( 'IPSocialLocker_ListTable' )) {

    /**
     * Class for display table of  social widget data
     */
    class IPSocialLocker_ListTable extends WP_List_Table
    {
        /**
         * Get a list of columns. The format is:
         * 'internal-name' => 'Title'
         *
         * @return array
         */
        public function get_columns() 
        {
            $posts_columns              = array();
            $posts_columns['title']     = __( 'Title' );
            $posts_columns['shortcode'] = __( 'Shortcode' );
            $posts_columns['theme']     = __( 'Theme' );
            $posts_columns['created']   = __( 'Created' );
            $posts_columns['actions']   = __( 'Actions' );
            return $posts_columns;
        }


        /**
         * Get a list of sortable columns. The format is:
         * 'internal-name' => 'orderby'
         * or
         * 'internal-name' => array( 'orderby', true )
         *
         * The second format will make the initial sorting order be descending
         *
         * @return array
         */
        public function get_sortable_columns() 
        {
            return array(
                'title'     => 'Title',
                'shortcode' => 'Shortcode',
                'theme'     => 'Theme',
                'created'   => 'Created',
            );
        }

        /**
         * Get a list of all, hidden and sortable columns, with filter applied
         *
         * @return array
         */
        public function get_column_info() 
        {
            $columns  = $this->get_columns();
            $hidden   = array();
            $sortable = array();
            $this->_column_headers = array( $columns, $hidden, $sortable );
            return $this->_column_headers;
        }

        /**
         * Prepares the list of items for displaying.
         * @uses WP_List_Table::set_pagination_args()
         *
         */
        public function prepare_items() 
        {
            global $wp_query, $per_page;
            
            $page = 1;
            if ( ! empty( $_GET['paged'] )) {
                $page = absint( $_GET['paged'] );
            }
            $args = array(
                'orderby'        => 'post_date',
                'order'          => 'DESC', 
                'post_type'      => 'ipsociallocker',
                'post_status'    => array(1),
                'posts_per_page' => 20,
                'paged'          => $page
            );
            $query = new WP_Query;
            $this->items = $query->query( $args );

            $total_items = $query->found_posts;
            $per_page    = $this->get_items_per_page( 'edit_ipsociallocker_per_page' );
            $per_page    = apply_filters( 'edit_posts_per_page', $per_page, 'ipsociallocker' );
            $total_pages = ceil( $total_items / $per_page );
            $this->set_pagination_args( array(
                'total_items' => $total_items,
                'total_pages' => $total_pages,
                'per_page' => $per_page
            ) );
        }

        /**
         * Get column title
         *
         * @param object $item
         * @return void
         */
        public function column_title( $item ) 
        {
            $title = $item->post_title;
            $link  = admin_url() . 'admin.php?page=wp-sociallocker&action=edit&id='.$item->ID;
            return '<strong><a class="row-title" href="' . $link . '">' . $title . '</a></strong>';
        }

        /**
         * Get column shortcode
         *
         * @param object $item
         * @return void
         */
        public function column_shortcode( $item ) 
        {
            $id = $item->ID;
            $sc = '[wp-sociallocker id="' . $id . '"][/wp-sociallocker]';
            return $sc;
        }

        /**
         * Get column theme
         *
         * @param object $item
         * @return void
         */
        public function column_theme( $item ) 
        {
            $setting = new IPSocialLocker_Setting( $item->ID );
            $theme   = $setting->getSetting( 'theme' );
            return $theme;
        }

        /**
         * Get column created
         *
         * @param object $item
         * @return void
         */
        public function column_created( $item ) 
        {
            $format = get_option('date_format') . ' ' . get_option('time_format');
            $date   = mysql2date( $format, $item->post_date );
            return $date;
        }

        /**
         * Get column actions
         *
         * @param object $item
         * @return void
         */
        public function column_actions( $item ) 
        {
            $linkEdit = admin_url() . 'admin.php?page=wp-sociallocker&action=edit&id='.$item->ID;
            $linkDel  = '#toDeleteLocker_'.$item->ID;
            $actions  = '<div class="ip_lockerActions">
                            <a class="ip_lockerEdit button button-primary" href="' . $linkEdit . '">' . __( 'Edit' ) . '</a>
                            <a class="ip_lockerDelete button" href="' . $linkDel . '">' . __( 'Delete' ) . '</a>
                        </div>';
            
            return $actions;
        }

        /**
         * Get column default
         *
         */
        public function column_default() 
        {
            return '';
        }
    }

}
?>