<?php
if ( ! class_exists( 'IPSocialLocker_Setting' )) {

    /**
     * Class for manage locker setting
     */
    class IPSocialLocker_Setting
    {
        /**
         * Take locker id
         *
         * @var string
         */
        protected $_lockerId;
        
        /**
         * Take locker setting
         *
         * @var array
         */
        protected $_settings;
        
        /**
         * Class construct
         *
         * @param int $lockerId
         * @return void
         */
        public function __construct( $lockerId )
        {
            $this->_lockerId = absint( $lockerId );
            $this->_prepare();
        }
        
        /**
         * Get all locker setting
         *
         * @return string
         */
        public function getSettings()
        {
            return $this->_settings;
        }
        
        /**
         * Get locker setting
         *
         * @param  string $key
         * @param  mixed  $default
         * @return string
         */
        public function getSetting( $key, $default = false, $allowEmpty = false )
        {
            $setting = $default;
            if ( $allowEmpty ) {
                if ( isset( $this->_settings[$key] ) ) {
                    $setting = $this->_settings[$key];
                }
            } else {
                if ( ! empty( $this->_settings[$key] ) ) {
                    $setting = $this->_settings[$key];
                }
            }
            return $setting;
        }
        
        /**
         * Get all locker setting
         *
         * @param  array $data
         * @return boolean
         */
        public function setSettings( $data )
        {
            $data     = (array)$data;
            $settings = (array)$this->_settings;
            $settings = array_merge( $settings, $data );
            $this->_settings = $settings;
            return $this->_update( $settings );
        }
        
        /**
         * Get locker setting
         *
         * @param  string $key
         * @param  string $value
         * @return boolean
         */
        public function setSetting( $key, $value )
        {
            $data = array(
                $key => $value
            );
            $settings = (array)$this->_settings;
            $settings = array_merge( $settings, $data );
            $this->_settings = $settings;
            return $this->_update( $settings );
        }
        
        /**
         * Reset locker setting
         *
         * @return boolean
         */
        public function reset()
        {
            $data = array( 'ipsociallocker' => 1 );
            return $this->_update( $data );
        }
        
        /**
         * Prepare class
         *
         * @return void
         */
        protected function _prepare()
        {
            $id = $this->_lockerId;
            if ( ! empty( $id )) {
                $metas = get_post_meta( $id, '_ip_locker_settings' );
                $meta  = array_shift( $metas );
                $this->_settings = maybe_unserialize( $meta );
            }
        }
        
        /**
         * Update settings
         *
         * @param  array $settings
         * @return boolean
         */
        protected function _update( $settings )
        {
            $settings = (array)$settings;
            return update_post_meta( $this->_lockerId, '_ip_locker_settings', $settings );
        }
    }

}

if ( ! class_exists( 'IPSocialLocker_Setting_Custom' )) {

    /**
     * Class for manage locker setting
     */
    class IPSocialLocker_Setting_Custom extends IPSocialLocker_Setting
    {
        /**
         * Take data setting
         *
         * @var array
         */
        protected $_data;
        
        /**
         * Take locker setting
         *
         * @var array
         */
        protected $_settings;
        
        /**
         * Class construct
         *
         * @param array $data
         * @return void
         */
        public function __construct( $data )
        {
            $this->_data = (array)$data;
            $this->_prepare();
        }
        
        /**
         * Get all locker setting
         *
         * @param  array $data
         * @return boolean
         */
        public function setSettings( $data )
        {
        }
        
        /**
         * Get locker setting
         *
         * @param  string $key
         * @param  string $value
         * @return boolean
         */
        public function setSetting( $key, $value )
        {
        }
        
        /**
         * Reset locker setting
         *
         * @return boolean
         */
        public function reset()
        {
        }
        
        /**
         * Prepare class
         *
         * @return void
         */
        protected function _prepare()
        {
            $data     = $this->_data;
            $settings = array();
            
            if ( isset( $data['locker_header'] )) {
                $settings['locker_header'] = apply_filters( 'single_post_title', $data['locker_header'] );
            }
            if ( isset( $data['locker_message'] )) {
                $settings['locker_message'] = $data['locker_message'];
            }
            
            //Social option
            $socopts = array(
                'fblike',
                'fbshare',
                'tweet',
                'twfollow',
                'gplus',
                'gpshare',
                'inshare',
            );
            foreach( $socopts as $tag ) {
                $id = $tag.'_available';
                if ( isset( $data[$id] )) {
                    $settings[$id] = preg_replace( '@[^a-zA-Z]@', '', $data[$id] );
                }
                $id = $tag.'_url';
                if ( isset( $data[$id] )) {
                    $settings[$id] = apply_filters( 'pre_link_url', $data[$id] );
                }
                $id = $tag.'_title';
                if ( isset( $data[$id] )) {
                    $settings[$id] = apply_filters( 'single_post_title', $data[$id] );
                }
                $id = $tag.'_type';
                if ( isset( $data[$id] )) {
                    $settings[$id] = absint( $data[$id] );
                }
            }
            
            //Design options
            if ( isset( $data['box_layout'] )) {
                $settings['box_layout'] = absint( $data['box_layout'] );
            }
            if ( isset( $data['box_design'] )) {
                $settings['box_design'] = absint( $data['box_design'] );
            }
            if ( isset( $data['button_design'] )) {
                $settings['button_design'] = absint( $data['button_design'] );
            }
            
            //Adv Functions
            if ( isset( $data['close_icon'] )) {
                $settings['close_icon'] = preg_replace( '@[^a-zA-Z]@', '', $data['close_icon'] );
            }
            if ( isset( $data['time_interval'] )) {
                $settings['time_interval'] = absint( $data['time_interval'] );
            }
            if ( isset( $data['ajax_support'] )) {
                $settings['ajax_support'] = preg_replace( '@[^a-zA-Z]@', '', $data['ajax_support'] );
            }
            if ( isset( $data['mobile_support'] )) {
                $settings['mobile_support'] = preg_replace( '@[^a-zA-Z]@', '', $data['mobile_support'] );
            }
            if ( isset( $data['highlight'] )) {
                $settings['highlight'] = preg_replace( '@[^a-zA-Z]@', '', $data['highlight'] );
            }
            if ( isset( $data['hide_member'] )) {
                $settings['hide_member'] = preg_replace( '@[^a-zA-Z]@', '', $data['hide_member'] );
            }
            if ( isset( $data['close_position'] )) {
                $settings['close_position'] = absint( $data['close_position'] );
            }
            if ( isset( $data['timer_position'] )) {
                $settings['timer_position'] = absint( $data['timer_position'] );
            }
            if ( isset( $data['show_alert_msg'] )) {
                $settings['show_alert_msg'] = preg_replace( '@[^a-zA-Z]@', '', $data['show_alert_msg'] );
            }
            if ( isset( $data['alert_message'] )) {
                $settings['alert_message'] = $data['alert_message'];
            }
            
            if ( isset( $data['socorder'] )) {
                $settings['button_order'] = $data['socorder'];
            }
            
            $this->_settings = $settings;
        }
        
        /**
         * Update settings
         *
         * @param  array $settings
         * @return boolean
         */
        protected function _update( $settings )
        {
        }
    }

}
?>