/**
 * Code in this file to be part of the wordpress plugin WP Social Locker developed by InstaProduct
 *
 * Some sections of code in this file extend existing functionality in the 
 * Social Locker for jQuery (http://codecanyon.net/item/social-locker-for-jquery/3408941) 
 * by OnePress (http://onepress-media.com/portfolio) with the permission of the developer Social Locker for jQuery.
 *
 * License of all codes in this file will be associated with the license held by the Social Locker for JQuery. 
 * Details license can be seen on http://codecanyon.net/licenses/extended
 */
var ipsl_statistic = {};

(function($){
    
    ipsl_statistic = {
        
        // available charts
        availableButtons: {
            "facebook-like": '#7089be',
            "facebook-share": '#566a93', 
            "twitter-tweet": '#3ab9e9', 
            "twitter-follow": '#1c95c3', 
            "google-plus": '#e26f61', 
            "google-share": '#ba5145', 
            "linkedin-share": '#006080',
            "timer": '#666666',
            "close": '#666666',
        },
        
        // charts selected by default
        defaultButtons: [
            "facebook-like", 
            "facebook-share", 
            "twitter-tweet", 
            "twitter-follow", 
            "google-plus",
            "google-share",
            "linkedin-share",
            "timer",
            "close",
        ],
        
        // default chart options that will be changed when the chart is drawing
        defaultOptions: {
            isStacked: true,
            fontSize: 11,
            legend: {
                position: 'in',
                format: 'dd MMM'
            },
            pointSize: 7,
            lineWidth: 3,
            //curveType: 'function',
            tooltip: {
                showColorCode: true,
                textStyle: {fontSize: '11', color: '#333'}
            },
            hAxis: {
                baselineColor: '#fff',
                gridlines: {color: '#fff'},
                textStyle: {fontSize: '11', color: '#333'},
                format: 'dd MMM'
            },
            vAxis: {
                baselineColor: '#000',
                gridlines: {color: '#f6f6f6'},
                textPosition: 'in',
                textStyle: {fontSize: '11', color: '#333'}
            },
            chartArea: { height: '170', width: '100%', top: 0 }
        },
        
        init: function() {
            var self = this;

            this.initButtonSelector();
            this.initTypeSelector();
            this.initDateRangeSelector();

            $(window).resize(function(){
                self.drawChart();
            });
        },
        
        /**
         * Inits buttons selector
         */
        initButtonSelector: function() {
            var self = this;
            
            // sets check boxes
            var index, className, isActive;
            
            // default values
            for(index in this.defaultButtons) {
                className = this.defaultButtons[index];
                $(".ipsl-selector." + className).addClass('active');
            }
            
            for(className in this.availableButtons) {
                    
                // the previous user selection
                if ( window.localStorage ) {
                
                    isActive = localStorage.getItem('iplocker-chart-' + className);
                    var item = $(".ipsl-selector." + className);
                    
                    if ( isActive ) {
                        if ( isActive == "yes" ) { 
                            item.removeClass('inactive');
                            item.addClass('active');
                            $(".ipsl-stats-table .ipsl-field-" + className).show();
                        }
                        else { 
                            item.addClass('inactive');
                            item.removeClass('active');
                            $(".ipsl-stats-table .ipsl-field-" + className).hide();
                        }
                    }
                }
                
                item.data('className', className);
                    
                // and the click event
                item.click(function(){
                    var className = $(this).data('className');
                    
                    if ( $(this).hasClass('active') ) {
                        $(this).removeClass('active');
                        $(this).addClass('inactive');
                        $(".ipsl-stats-table .ipsl-field-" + className).hide();
                        if ( window.localStorage ) localStorage.setItem('iplocker-chart-' + className, "no");
                    } else { 
                        $(this).addClass('active');
                        $(this).removeClass('inactive');
                        $(".ipsl-stats-table .ipsl-field-" + className).show();
                        if ( window.localStorage ) localStorage.setItem('iplocker-chart-' + className, "yes");
                    }
                    
                    self.drawChart();
                    return false;
                });
            }
        },
        
        /**
         * Inits types selector.
         */
        initTypeSelector: function() {
            var self = this;
            
            $("#ipsl-chart-type").find("button").click(function(){
                var type = $(this).data('value');
                if ( window.localStorage ) window.localStorage.setItem('iplocker-admin-chart-type', type);
                self.drawChart(type);
                
                if ( type == "detailed" ) {
                    
                }
            });

            if ( window.localStorage ) {
                var type = localStorage.getItem('iplocker-admin-chart-type');
                var btnType = '.type-' + type;
                $("#ipsl-chart-type").find("button.active").removeClass('active');
                $("#ipsl-chart-type").find(btnType).click();
            } 
        },
        
        /**
         * Inits date range selector.
         */
        initDateRangeSelector: function() {
            var self = this;
            
            $('#date-start')
                .datepicker()
                .bind('changeDate', function(ev){
                    $('#date-start').datepicker('hide');
                });
                
            $('#date-end')
                .datepicker()
                .bind('changeDate', function(ev){
                    $('#date-end').datepicker('hide');
                });
        },
        
        /**
         * Returns selected by user social buttons stats to show.
         */
        getActiveButtons: function() {
            
            var result = [];
            var activeItems = $(".ipsl-selector.active");
            activeItems.each(function(){
                var className = $(this).data('className');
                result.push(className);
            });
            return result;
        },
        
        drawChart: function (type) {
            var data = [], index, button;
            
            this.currentType = type || this.currentType || 'total';
            var options = $.extend({}, this.defaultOptions);
            var activeButtons = this.getActiveButtons();

            // Create the data table.
            var dataTable = new google.visualization.DataTable();
            dataTable.addColumn('date', 'Date');
            
            if (this.currentType == 'total') {
                chartFunction = 'AreaChart';
                
                options.legend.position = 'in';
                options.areaOpacity = 0.1;
                options.colors = ['#4691b1'];
                
                dataTable.addColumn('number', 'Total social interactions');
                dataTable.addColumn({type:'string',role:'tooltip'});
                
                data = [];
                for(var rowIndex in chartData) {
                    var row = chartData[rowIndex];
                    
                    var totalCount = 0;
                    for(index in activeButtons) {
                        button = activeButtons[index];
                        totalCount += row[button];
                    }
                    
                    var chartRow = [ row['date'], totalCount, '' + totalCount ];
                    data.push(chartRow);
                }

            } else if (this.currentType == 'detailed') {
                chartFunction = 'LineChart';
                
                options.colors = [];
                options.legend.position = 'none';
                
                for(index in activeButtons) {
                    button = activeButtons[index];
                    var color = this.availableButtons[button];

                    options.colors.push(color);
                    dataTable.addColumn('number', '');
                }

                data = [];
                for(var rowIndex in window.chartData) {
                    var row = window.chartData[rowIndex];

                    var chartRow = [ row['date'] ];
                    for(index in activeButtons) {
                        button = activeButtons[index];
                        chartRow.push( row[button] );
                    }
                    data.push(chartRow);
                }

            } else if (this.currentType == 'helpers') {
                chartFunction = 'ColumnChart';
                
                options.legend.position = 'in';
                options.colors = ['#4691b1', '#333', '#ddd'];
                
                dataTable.addColumn('number', 'Total social interactions');
                dataTable.addColumn('number', 'by Timer');
                dataTable.addColumn('number', 'by Close Icon'); 
                
                data = [];
                for(var rowIndex in chartData) {
                    var row = chartData[rowIndex];
                    
                    var totalCount = 0;
                    for(index in activeButtons) {
                        button = activeButtons[index];
                        totalCount += row[button];
                    }
                    
                    var chartRow = [ row['date'], totalCount, row['timer'], row['cross'] ];
                    data.push(chartRow);
                }
            }

            dataTable.addRows(data);
            
            // Instantiate and draw our chart, passing in some options.
            var chart = new google.visualization[chartFunction](document.getElementById('ipsl-chart'));
            chart.draw(dataTable, options);
        }
    };

    $(function(){
       ipsl_statistic.init();
    });
    
})(jQuery)
