<?php
/*
Plugin Name: WP Social Locker
Plugin URI: 
Description: Plugin that works to create a social locker in your content website
Version: 1.3
Author: InstaPRoduct
Author URI: http://insta-product.com/
*/

/*  
    LICENSE: This source file to be part of a system developed by InstaPRoduct. 
    All copyrights use this file and the code in it owned by InstaPRoduct. 
    It is strictly forbidden to use, copy, modify or distribute this file and 
    the code in it without the permission of the developer.
*/

//Change this value for rebranding plugin
define( 'IPSOCIALLOCKER_TITLE', 'Arn Social Locker' );

require_once( plugin_dir_path( __FILE__ ) . "includes/setting.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/admin.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/ajax.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/factory.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/db.php" );

/**
 * Class for generate social content
 */
if ( ! class_exists( 'IPSocialLocker' )) {

    class IPSocialLocker
    {
        /**
         * Setup Plugin
         */
        public function setup()
        {
            $hook = strtolower( IPSOCIALLOCKER_TITLE );
            $hook = preg_replace( '@[^a-zA-Z0-9\-]@', '-', $hook );
            
            //Install Plugin
            register_activation_hook( __FILE__, array( 'IPSocialLocker', 'installDb' ) );
            
            //Hook for plugin loaded
            add_action( 'plugins_loaded', array( 'IPSocialLocker', 'updateDb' ) );
            
            //Register admin menu
            add_action( 'admin_menu', array( 'IPSocialLocker', 'addAdminMenu' ) );
            
            //Add Admin style
            add_action( 'admin_print_styles', array( 'IPSocialLocker', 'printAdminStyle' ), 1000 );
            add_action( 'admin_footer-toplevel_page_wp-sociallocker', array( 'IPSocialLocker', 'printAdminScript' ), 1000 );
            add_action( 'admin_footer-'.$hook.'_page_wp-sociallocker-add', array( 'IPSocialLocker', 'printAdminScript' ), 1000 );
            add_action( 'admin_print_footer_scripts', array( 'IPSocialLocker', 'printGlobalAdminScript' ), 1000 );

            //Ajax handler
            add_action( 'admin_init', array( 'IPSocialLocker', 'doAjax' ) );

            //Add Editor Button
            add_action( 'admin_init', array( 'IPSocialLocker', 'addEditorButton' ) );
            
            //Add Editor Dialog
            add_action( 'tiny_mce_preload_dialogs', array( 'IPSocialLocker', 'createEditor' ) );
            add_action( 'after_wp_tiny_mce', array( 'IPSocialLocker', 'createEditor' ) );
            
            //Add Shortcode
            add_shortcode( 'wp-sociallocker', array( 'IPSocialLocker', 'factory' ) );
            add_filter( 'the_content', array( 'IPSocialLocker', 'postLocker' ) );
            
            //Add front style
            add_action('wp_head', array( 'IPSocialLocker', 'printStyle' ) );
            
            //Add js library
            if ( ! is_admin() ) {
                add_action( "wp_enqueue_scripts", array( 'IPSocialLocker', 'libScript' ), 11 );
                //Add front script
                add_action('wp_enqueue_scripts', array( 'IPSocialLocker', 'printScript' ), 12 );
            }
            
            // Add meta box option
            add_action( 'add_meta_boxes', array( 'IPSocialLocker', 'addMetaBox' ) );
            add_action( 'save_post', array( 'IPSocialLocker', 'savePagePopup' ) );

        }
        
        /**
         * Add administrator menu
         *
         * @return void
         */
        public function addAdminMenu()
        {
            
            add_menu_page( 
                IPSOCIALLOCKER_TITLE, 
                IPSOCIALLOCKER_TITLE, 
                9, 
                'wp-sociallocker', 
                array( 'IPSocialLocker', 'adminPage' ), 
                plugin_dir_url( __FILE__ ) . 'img/menu_icon.png'
            );
            add_submenu_page( 
                'wp-sociallocker', 
                'All Social Lockers', 
                'All Social Lockers', 
                9, 
                'wp-sociallocker',
                array( 'IPSocialLocker', 'adminPage' )
            );
            add_submenu_page( 
                'wp-sociallocker', 
                'Add Social Locker', 
                'Add Social Locker', 
                9, 
                'wp-sociallocker-add', 
                array( 'IPSocialLocker', 'adminAdd' )
            );
            add_submenu_page( 
                'wp-sociallocker', 
                'Settings', 
                'Settings', 
                9, 
                'wp-sociallocker-setting', 
                array( 'IPSocialLocker', 'adminSetting' )
            );
            add_submenu_page( 
                'wp-sociallocker', 
                'Table Stats', 
                'Table Stats', 
                9, 
                'wp-sociallocker-stats', 
                array( 'IPSocialLocker', 'adminStats' )
            );
            add_submenu_page( 
                'wp-sociallocker', 
                'Graph Stats', 
                'Graph Stats', 
                9, 
                'wp-sociallocker-graph', 
                array( 'IPSocialLocker', 'graphStats' )
            );
        }
        
        /**
         * Processing ajax request
         *
         * @return void
         */
        public function doAjax()
        {
            $ajax = new IPSocialLocker_Ajax();
            return $ajax->exec();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public function adminPage()
        {
            $display = new IPSocialLocker_Admin();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $display->edit();
            } else {
                $display->index();
            }
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public function adminAdd()
        {
            $display = new IPSocialLocker_Admin();
            $display->manage();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public function adminSetting()
        {
            $display = new IPSocialLocker_Admin();
            $display->adminSetting();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public function adminStats()
        {
            $display = new IPSocialLocker_Admin();
            $display->stats();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public function graphStats()
        {
            $display = new IPSocialLocker_Admin();
            $display->graphStats();
        }
        
        /**
         * Install Db
         *
         * @return void
         */
        public function installDb()
        {
            $db = new IPSocialLocker_Db();
            $db->install();
        }
        
        /**
         * Update Db
         *
         * @return void
         */
        public function updateDb()
        {
            $db = new IPSocialLocker_Db();
            $db->update();
        }
        
        /**
         * Add administrator meta box
         *
         * @return void
         */
        public function addMetaBox()
        {
            $screens = array( 'post', 'page' );
            foreach ($screens as $screen) {
                add_meta_box(
                    'ip_box_locker',
                    __( 'Post Locker' ),
                    array( 'IPSocialLocker', 'metaBoxContent' ),
                    $screen,
                    'side'
                );
            }
        }
        
        /**
         * Content for administrator meta box
         *
         * @return void
         */
        public function metaBoxContent( $post )
        {
            $display = new IPSocialLocker_Admin();
            $display->metaBox( $post );
        }
        
        /**
         * Save page/post locker
         *
         * @return void
         */
        public function savePagePopup( $post_id )
        {
            if ( 'page' == $_POST['post_type'] ) {
                if ( ! current_user_can( 'edit_page', $post_id ) ) {
                    return;
                }
            } else {
                if ( ! current_user_can( 'edit_post', $post_id ) ) {
                    return;
                }
            }
            // Check if the user intended to change this value.
            if ( ! isset( $_POST['ip_select_locker_nonce'] ) ) {
                return;
            }
            $post_ID = $_POST['post_ID'];
            $id      = sanitize_text_field( $_POST['ip_locker_select'] );
            update_post_meta( $post_ID, '_ip_post_lock', $id );
        }
        
        /**
         * Main method for create Locker
         *
         * @param  array  $atts
         * @param  string $content
         * @return string
         */
        public function factory( $atts, $content = '')
        {
            $factory = new IPSocialLocker_Factory();
            return $factory->create( $atts, $content );
        }
        
        /**
         * Main method for create Post Locker
         *
         * @param  string $content
         * @return string
         */
        public function postLocker( $content = '')
        {
            $factory = new IPSocialLocker_Factory();
            return $factory->postLocker( $content );
        }
        
        /**
         * Initialize locker
         *
         * @return void
         */
        public function frontInit()
        {
            global $ipsp_factory;
            $ipsp_factory = new IPSocialLocker_Factory();
            $ipsp_factory->init();
        }
         
        
        /**
         * Hook function for add button to editor
         *
         * @return void
         */
        public function addEditorButton() 
        {
            if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') ) {
                return;
            }
            if ( get_user_option('rich_editing') == 'true') {
                add_filter( 'mce_external_plugins', array( 'IPSocialLocker', 'addTinymcePlugin' ));
                add_filter( 'mce_buttons', array( 'IPSocialLocker', 'registerTinymceButton' ));
            }
        }

        /**
         * Register button to TinyMce system
         *
         * @param  array $button
         * @return void
         */
        function registerTinymceButton( $buttons ) 
        {
           array_push($buttons, "|", "ipsociallocker");
           return $buttons;
        }

        /**
         * Register TinyMce plugin
         *
         * @param  array $plugin_array
         * @return void
         */
        function addTinymcePlugin( $plugin_array ) 
        {
           $plugin_array['ipsociallocker'] = plugin_dir_url( __FILE__ ) . 'js/editor_plugin.js';
           return $plugin_array;
        }
        
        /**
         * Content editor dialog
         *
         * @return void
         */
        public function createEditor()
        {
            $display = new IPSocialLocker_Admin();
            $display->editor();
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public function printAdminStyle()
        {
            $href = plugin_dir_url( __FILE__ ) . 'css/admin.css';
            echo '<link media="all" type="text/css" href="' . $href . '" rel="stylesheet">';
        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public function printAdminScript($hook)
        {
            $src1 = plugin_dir_url( __FILE__ ) . 'js/admin.js';
            echo '<script type="text/javascript" src="' . $src1 . '"></script>';
        }

        /**
         * Print Global Admin Script
         *
         * @return void
         */
        public function printGlobalAdminScript($hook)
        {
            $src1 = plugin_dir_url( __FILE__ ) . 'js/admin-global.js';
            echo '<script type="text/javascript" src="' . $src1 . '"></script>';
        }

        /**
         * Print style
         *
         * @return void
         */
        public function printStyle()
        {
        ?>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/style.css" rel="stylesheet">
        <?php
        }

        /**
         * Print script
         *
         * @return void
         */
        public function printScript()
        {
            wp_deregister_script('iplocker-front-script');
            wp_enqueue_script(
                'iplocker-front-script',
                plugin_dir_url( __FILE__ ) . 'js/script.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Lib script
         *
         * @return void
         */
        public function libScript()
        {
            wp_deregister_script('jquery');
            wp_register_script('jquery', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js", false, null);
            wp_enqueue_script('jquery');
            
            wp_deregister_script('jquery-ui');
            wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.3/jquery-ui.min.js", false, null);
            wp_enqueue_script('jquery-ui');
        }
    }

}
//Run plugin
IPSocialLocker::setup();
?>